@@ -80,7 +80,7 @@ public:
                              See <a href='http://defuse.ca/audits/encfs.htm'>defuse.ca/audits/encfs.htm</a> for more information."))
                      },
                 step { passwordChooser() },
-                step { directoryPairChooser(DirectoryPairChooserWidget::RequireEmptyDirectories) },
+                step { directoryPairChooser(DirectoryPairChooserWidget::SkipDevicePicker) },
                 step { activitiesChooser() }
             }
         },
@@ -103,7 +103,7 @@ public:
                              which confirms this."))
                      },
                 step { passwordChooser() },
-                step { directoryPairChooser(DirectoryPairChooserWidget::RequireEmptyDirectories) },
+                step { directoryPairChooser() },
                 step {
                     cryfsCypherChooser(),
                     activitiesChooser()
@@ -112,6 +112,12 @@ public:
         }
     };
 
+    // to suggest the highest priority to the user as a starting value
+    QMap<QString, int> priorities = {
+        { "encfs", 1 },
+        { "cryfs", 2 }
+    };
+
     template <typename ClickHandler>
     QPushButton *addDialogButton(const QString &icon, const QString &title, ClickHandler clickHandler)
     {
@@ -150,8 +156,9 @@ public:
 
         // Loading the backends to the combo box
         for (const auto& key: logic.keys()) {
-            firstStepModule->addItem(key, key.translation());
+            firstStepModule->addItem(key, key.translation(), priorities.value(key));
         }
+        firstStepModule->checkBackendAvailable();
     }
 
     void setCurrentModule(DialogDsl::DialogModule *module)
@@ -288,7 +295,7 @@ VaultCreationWizard::VaultCreationWizard(QWidget *parent)
     : QDialog(parent)
     , d(new Private(this))
 {
-    setWindowTitle(i18n("Create a New Vault"));
+    setWindowTitle(i18nc("@title:window", "Create a New Vault"));
 }
 
 
